<?php return array (
  'providers' => 
  array (
    0 => 'Modules\\LandingPage\\Providers\\LandingPageServiceProvider',
    1 => 'Modules\\LandingPage\\Providers\\AddMenuProvider',
  ),
  'eager' => 
  array (
    0 => 'Modules\\LandingPage\\Providers\\LandingPageServiceProvider',
    1 => 'Modules\\LandingPage\\Providers\\AddMenuProvider',
  ),
  'deferred' => 
  array (
  ),
);