import { jsx } from "react/jsx-runtime";
import { V as createSvgIcon } from "../server-entry.mjs";
const ReplyIcon = createSvgIcon(
  /* @__PURE__ */ jsx("path", { d: "M10 9V5l-7 7 7 7v-4.1c5 0 8.5 1.6 11 5.1-1-5-4-10-11-11z" }),
  "ReplyOutlined"
);
export {
  ReplyIcon as R
};
//# sourceMappingURL=Reply-cd05287b.mjs.map
